@@ -1,4 +1,5 @@
 import mimetypes
+from collections.abc import AsyncIterable, Awaitable
 from dataclasses import asdict, dataclass, field, fields
 from datetime import datetime
 from enum import IntEnum
@@ -145,11 +146,11 @@ class LoginStatus(IntEnum):
 
 @dataclass
 class Login(ModelBase):
-    sn: str
+    sn: int
     status: LoginStatus
     adapter: str
-    platform: Optional[str] = None
-    user: Optional[User] = None
+    platform: str
+    user: User
     features: list[str] = field(default_factory=list)
 
     __converter__ = {"user": User.parse, "status": LoginStatus}
@@ -172,17 +173,25 @@ class Login(ModelBase):
     def parse(cls, raw: dict):
         if "self_id" in raw and "user" not in raw:
             raw["user"] = {"id": raw["self_id"]}
+        if "sn" not in raw:
+            raw["sn"] = 0
         if "adapter" not in raw:
             raw["adapter"] = "satori"
+        if "status" not in raw:
+            raw["status"] = LoginStatus.ONLINE
         return super().parse(raw)
 
     @property
     def id(self) -> str:
-        if not self.user:
-            raise ValueError(f"Login {self.sn} has not complete yet")
         return self.user.id
 
 
+@dataclass
+class LoginPartial(Login):
+    platform: Optional[str] = None
+    user: Optional[User] = None
+
+
 @dataclass
 class ArgvInteraction(ModelBase):
     name: str
@@ -237,10 +246,10 @@ class Identify(ModelBase):
 
 @dataclass
 class Ready(ModelBase):
-    logins: list[Login]
+    logins: list[LoginPartial]
     proxy_urls: list[str] = field(default_factory=list)
 
-    __converter__ = {"logins": lambda raw: [Login.parse(login) for login in raw]}
+    __converter__ = {"logins": lambda raw: [LoginPartial.parse(login) for login in raw]}
 
     def dump(self):
         return asdict(self)
@@ -260,10 +269,10 @@ class MetaPayload(ModelBase):
 class Meta(ModelBase):
     """Meta 数据"""
 
-    logins: list[Login]
+    logins: list[LoginPartial]
     proxy_urls: list[str] = field(default_factory=list)
 
-    __converter__ = {"logins": lambda raw: [Login.parse(login) for login in raw]}
+    __converter__ = {"logins": lambda raw: [LoginPartial.parse(login) for login in raw]}
 
     def dump(self):
         return asdict(self)
@@ -410,7 +419,7 @@ class Event(ModelBase):
             raw["sn"] = raw["id"]
         if "platform" in raw and "self_id" in raw and "login" not in raw:
             raw["login"] = {
-                "sn": raw["self_id"],
+                "sn": 0,
                 "platform": raw["platform"],
                 "user": {"id": raw["self_id"]},
                 "status": LoginStatus.ONLINE,
@@ -497,6 +506,29 @@ class PageDequeResult(PageResult[T]):
         return res
 
 
+class IterablePageResult(Generic[T], AsyncIterable[T], Awaitable[PageResult[T]]):
+    def __init__(
+        self, func: Callable[[Optional[str]], Awaitable[PageResult[T]]], initial_page: Optional[str] = None
+    ):
+        self.func = func
+        self.next_page = initial_page
+
+    def __await__(self):
+        return self.func(self.next_page).__await__()
+
+    def __aiter__(self):
+        async def _gen():
+            while True:
+                result = await self.func(self.next_page)
+                for item in result.data:
+                    yield item
+                self.next_page = result.next
+                if not self.next_page:
+                    break
+
+        return _gen()
+
+
 Direction: TypeAlias = Literal["before", "after", "around"]
 Order: TypeAlias = Literal["asc", "desc"]
 
